@@ -1,4 +1,5 @@
-#' Find Nearest GSOD Stations to Specified Latitude and Longitude
+
+#' Find nearest GSOD stations to specified latitude and longitude
 #'
 #'Given a latitude and longitude value entered as decimal degrees (DD),
 #'this function returns a list of STNID values, which can be used in
@@ -28,12 +29,12 @@
 #' @author Adam H Sparks, \email{adamhsparks@gmail.com}
 #' @export
 nearest_stations <- function(LAT, LON, distance) {
-  original_timeout <- options("timeout")[[1]]
-  options(timeout = 300)
-  on.exit(options(timeout = original_timeout), add = TRUE)
-  stations <- as.data.frame(get_station_list())
-  dists <- fields::rdist.earth(as.matrix(stations[c("LAT", "LON")]),
+  # load current local copy of isd_history
+
+  isd_history <- as.data.frame(isd_history)
+  
+  dists <- fields::rdist.earth(as.matrix(isd_history[c("LAT", "LON")]),
                                matrix(c(LAT, LON), ncol = 2), miles = FALSE)
   nearby <- which(dists[, 1] < distance)
-  return(stations[as.numeric(nearby), ]$STNID)
+  return(isd_history[as.numeric(nearby), ]$STNID)
 }
