@@ -3,8 +3,7 @@
 context("nearest_stations")
 
 test_that("nearest stations returns character value station IDs", {
-  skip_on_cran()
-
+  
   n <- nearest_stations(LAT = -27.5598, LON = 151.9507, distance = 100)
   expect_length(n, 15)
   expect_type(n, "character")
@@ -23,5 +22,8 @@ test_that("nearest stations returns character value station IDs", {
                     "949999-00186",
                     "955510-99999",
                     "955550-99999"))
+  rm(n)
 
 })
+
+
